==> haskell-floatinghex-0.4-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: FloatingHex
version: 0.4
id: FloatingHex-0.4-IA96cFYpHgo1eoJYwCourV
key: FloatingHex-0.4-IA96cFYpHgo1eoJYwCourV
license: BSD3
copyright: Levent Erkok
maintainer: erkokl@gmail.com
synopsis: Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.
    .
    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.
    .
    For details, please see: <http://github.com/LeventErkok/FloatingHex/>
category: Tools
author: Levent Erkok
exposed: True
indefinite: False
exposed-modules:
    Data.Numbers.FloatingHex
abi: 3438e7d049d5b054b4f39c8f3d5cbc0c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/FloatingHex-0.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/FloatingHex-0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/FloatingHex-0.4
hs-libraries: HSFloatingHex-0.4-IA96cFYpHgo1eoJYwCourV
depends:
    base-4.10.0.0 template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             template-haskell-2.12.0.0=612ee923b47f5e11502cef08338c9f82
haddock-interfaces: /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html: /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floatinghex-0.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: FloatingHex
version: 0.4
id: FloatingHex-0.4-FRkUIMjJcdjL5s7KRLamn8
key: FloatingHex-0.4-FRkUIMjJcdjL5s7KRLamn8
license: BSD3
copyright: Levent Erkok
maintainer: erkokl@gmail.com
synopsis: Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.
    .
    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.
    .
    For details, please see: <http://github.com/LeventErkok/FloatingHex/>
category: Tools
author: Levent Erkok
exposed: True
indefinite: False
exposed-modules:
    Data.Numbers.FloatingHex
abi: 7f14cf259699f1f7915c238a67eb2229
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/FloatingHex-0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/FloatingHex-0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/FloatingHex-0.4
hs-libraries: HSFloatingHex-0.4-FRkUIMjJcdjL5s7KRLamn8
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html: /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
